==> avc-jyb-1.0.0-sources.jar: io/agora/avc/app/group/GroupTailoredAdapter.kt <==
package io.agora.avc.app.group

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import io.agora.avc.R
import io.agora.avc.app.address.AddressBookNode
import io.agora.avc.app.address.ErrorViewHolder
import io.agora.avc.databinding.ItemErrorViewBinding
import io.agora.avc.databinding.ItemGroupTailoredMemberBinding
import io.agora.frame.base.BaseRecyclerAdapter

class GroupTailoredAdapter(private val onRefreshClicked: () -> Unit) :
    BaseRecyclerAdapter<AddressBookNode, RecyclerView.ViewHolder>() {
    override fun convert(
        holder: RecyclerView.ViewHolder,
        items: MutableList<AddressBookNode>?,
        position: Int
    ) {
        when (holder) {
            is ErrorViewHolder -> {
                holder.binding.btnConfirm.setOnClickListener {
                    onRefreshClicked.invoke()
                }
            }
            is GroupTailoredViewHolder -> {
                holder.onBind(items?.get(position)) {
                    items?.let {
                        it.removeAt(holder.adapterPosition)
                        notifyItemRemoved(holder.adapterPosition)
                    }
                }
            }
        }
    }

    override fun bindViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        return when (viewType) {
            R.layout.item_error_view -> {
                ErrorViewHolder(
                    ItemErrorViewBinding.inflate(
                        LayoutInflater.from(parent.context),
                        parent,
                        false
                    )
                )
            }
            else -> {
                GroupTailoredViewHolder(
                    ItemGroupTailoredMemberBinding.inflate(
                        LayoutInflater.from(parent.context),
                        parent,
                        false
                    )
                )
            }
        }
    }

    override fun getItemViewType(position: Int): Int {
        return data[position].viewType
    }
}

==> avc-jyb-1.0.3-sources.jar: io/agora/avc/app/group/GroupTailoredAdapter.kt <==
package io.agora.avc.app.group

import android.view.LayoutInflater
import android.view.ViewGroup
import androidx.recyclerview.widget.RecyclerView
import io.agora.avc.R
import io.agora.avc.app.address.AddressBookNode
import io.agora.avc.app.address.ErrorViewHolder
import io.agora.avc.databinding.AvcItemErrorViewBinding
import io.agora.avc.databinding.AvcItemGroupTailoredMemberBinding
import io.agora.frame.base.BaseRecyclerAdapter

class GroupTailoredAdapter(private val onRefreshClicked: () -> Unit) :
    BaseRecyclerAdapter<AddressBookNode, RecyclerView.ViewHolder>() {
    override fun convert(
        holder: RecyclerView.ViewHolder,
        items: MutableList<AddressBookNode>?,
        position: Int
    ) {
        when (holder) {
            is ErrorViewHolder -> {
                holder.binding.btnConfirm.setOnClickListener {
                    onRefreshClicked.invoke()
                }
            }
            is GroupTailoredViewHolder -> {
                holder.onBind(items?.get(position)) {
                    items?.let {
                        it.removeAt(holder.adapterPosition)
                        notifyItemRemoved(holder.adapterPosition)
                    }
                }
            }
        }
    }

    override fun bindViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        return when (viewType) {
            R.layout.avc_item_error_view -> {
                ErrorViewHolder(
                    AvcItemErrorViewBinding.inflate(
                        LayoutInflater.from(parent.context),
                        parent,
                        false
                    )
                )
            }
            else -> {
                GroupTailoredViewHolder(
                    AvcItemGroupTailoredMemberBinding.inflate(
                        LayoutInflater.from(parent.context),
                        parent,
                        false
                    )
                )
            }
        }
    }

    override fun getItemViewType(position: Int): Int {
        return data[position].viewType
    }
}
